/**************menu part start*****************/
.home_menu {
	.main-menu-item {
		padding-left: 89px;
	}

	.menu_btn {
		&:hover a {
			color: $white-color !important;
		}
	}

	.main-menu-item {
		justify-content: start !important;
	}
}

.single_page_menu {
	.main-menu-item {
		justify-content: flex-end;

		ul {
			li .nav-link {
				&:hover {
					color: $btn_bg !important;
				}

			}
		}
	}
}
.single_page_menu.menu_fixed{
	.main-menu-item {
		justify-content: flex-end;

		ul {
			li .nav-link {
				&:hover {
					color: $black_color !important;
				}

			}
		}
	}
}
.main_menu {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	z-index: 999;

	.navbar-brand {
		padding-top: 0rem;
		padding-bottom: 0px;
	}

	.navbar {
		padding: 0px;
	}

	.main-menu-item {
		ul {
			li .nav-link {
				color: $menu_color;
				font-size: 16px;
				padding: 38px 19px;
				font-family: $font_stack_1;
				text-transform: capitalize;
				line-height: 12px;

				@media #{$medium_device} {
					padding: 35px 20px;
				}
			}
		}
	}
}

.menu_fixed {
	position: fixed;
	z-index: 9999 !important;
	width: 100%;
	box-shadow: 0px 10px 15px rgba(0, 0, 0, 0.05);
	top: 0;

	&:after {
		position: absolute;
		left: 0;
		top: 0;
		width: 100%;
		height: 100%;
		content: "";
		background-color: $btn_bg;
		z-index: -1;
		opacity: .7;
	}

	.main-menu-item {
		padding-right: 0px;
		justify-content: flex-end !important;
	}

}

.dropdown {
	.dropdown-menu {
		transition: all 0.5s;
		overflow: hidden;
		transform-origin: top center;
		transform: scale(1, 0);
		display: block;
		border: 0px solid transparent;
		background-color: #fa4c4c;
		margin-top: 0px;
		.dropdown-item {
			font-size: 14px;
			padding: 8px 20px !important;
			color: #fff !important;
			background-color: #fa4c4c;
			text-transform: capitalize;
		}

	}

	&:hover {
		.dropdown-menu {
			transform: scale(1);
		}
	}
}

@media #{$small_mobile} {
	.main_menu {
		padding: 20px 0px;
	}

	.home_menu .main-menu-item {
		padding-left: 0px;
	}

	.main_menu .main-menu-item {
		text-align: left !important;

		.nav-item {
			padding: 10px 15px !important;

			.nav-link {
				padding: 5px 15px !important;
				color: $black_color;
			}
		}
	}

	.navbar-collapse {
		z-index: 9999 !important;
		position: absolute;
		left: 0;
		top: 50px;
		width: 100%;
		background-color: $white-color;
		text-align: center !important;
	}

	.dropdown {
		.dropdown-menu {
			transform: scale(1, 0);
			display: none;
			margin-top: 10px;
		}

		&:hover {
			.dropdown-menu {
				transform: scale(1);
				display: block;
				color: $btn_bg;
			}
		}

		.dropdown-item:hover {
			color: $btn_bg !important;
		}
	}

	.navbar-brand img {
		max-width: 100px;
	}

	.navbar-light .navbar-toggler {
		border-color: transparent;
		position: absolute;
		right: 0;
	}

}

@media #{$large_mobile} {
	.main_menu {
		padding: 20px 0px;
	}

	.home_menu .main-menu-item {
		padding-left: 0px;
	}

	.main_menu .main-menu-item {
		text-align: left !important;

		.nav-item {
			padding: 10px 15px !important;

			.nav-link {
				padding: 5px 15px !important;
				color: $black_color;
			}
		}
	}

	.navbar-collapse {
		z-index: 9999 !important;
		position: absolute;
		left: 0;
		top: 50px;
		width: 100%;
		background-color: $white-color;
		text-align: center !important;
	}

	.dropdown {
		.dropdown-menu {
			transform: scale(1, 0);
			display: none;
			margin-top: 10px;
		}

		&:hover {
			.dropdown-menu {
				transform: scale(1);
				display: block;
				color: $btn_bg;
			}
		}

		.dropdown-item:hover {
			color: $btn_bg !important;
		}
	}

	.navbar-brand img {
		max-width: 100px;
	}

	.navbar-light .navbar-toggler {
		border-color: transparent;
		position: absolute;
		right: 0;
	}
}

@media #{$tab_device} {
	.main_menu {
		padding: 20px 0px;
	}

	.home_menu .main-menu-item {
		padding-left: 0px;
	}

	.main_menu .main-menu-item {
		text-align: left !important;

		.nav-item {
			padding: 10px 15px !important;

			.nav-link {
				padding: 5px 15px !important;
				color: $black_color;
			}
		}
	}

	.navbar-collapse {
		z-index: 9999 !important;
		position: absolute;
		left: 0;
		top: 50px;
		width: 100%;
		background-color: $white-color;
		text-align: center !important;
	}

	.dropdown {
		.dropdown-menu {
			transform: scale(1, 0);
			display: none;
			margin-top: 10px;
		}

		&:hover {
			.dropdown-menu {
				transform: scale(1);
				display: block;
				color: $btn_bg;
			}
		}

		.dropdown-item:hover {
			color: $btn_bg !important;
		}
	}

	.navbar-brand img {
		max-width: 100px;
	}

	.navbar-light .navbar-toggler {
		border-color: transparent;
		position: absolute;
		right: 0;
	}
}

.dropdown-menu {
	border: 0px solid rgba(0, 0, 0, .15) !important;
	background-color: #fafafa;
}

.dropdown:hover {
	.dropdown-menu {
		display: block;
	}
}

.menu_icon {
	&:after {
		position: absolute;
		content: "\e68e";
		top: -16px;
		right: 11px;
		font-family: 'themify';
		color: #fff;
		font-size: 33px;
		width: 20px;
		height: 20px;
	}
}